@@ -1,7 +1,8 @@
 #' Subcorpus With Date Filter
 #'
-#' Generates a subcorpus by restricting it to a specific time window
+#' Generates a subcorpus by restricting it to a specific time window.
 #'
+#' @param ... Not used.
 #' @param object \code{\link{textmeta}} object
 #' @param text Not necessary if \code{object} is specified, else should be
 #' \code{object$text}
@@ -9,9 +10,11 @@
 #' \code{object$meta}
 #' @param s.date Start date of subcorpus as date object
 #' @param e.date End date of subcorpus as date object
+#' @param filtermeta Logical: Should the meta component be filtered, too?
 #' @return \code{\link{textmeta}} object if \code{object} is specified,
 #' else only the filtered \code{text}. If a \code{\link{textmeta}} object is
-#' returned its meta data are filtered to those texts which appear in the corpus.
+#' returned its meta data are filtered to those texts which appear in the corpus
+#' by default (\code{filtermeta}).
 #' @keywords manip
 #' @examples
 #' texts <- list(A="Give a Man a Fish, and You Feed Him for a Day.
@@ -29,21 +32,42 @@
 #' subcorpus$meta
 #' subcorpus$text
 #' @export filterDate
-filterDate <- function(object, text = object$text, meta = object$meta,
-  s.date = min(meta$date, na.rm = TRUE),
-  e.date = max(meta$date, na.rm = TRUE)){
+filterDate <- function(...) UseMethod("filterDate")
 
-  returnTextmeta <- TRUE
-  if(missing(object)){
-    object <- textmeta(meta = meta, text = text)
-    returnTextmeta <- FALSE
-  }
-  stopifnot(is.textmeta(object), length(s.date) == 1, length(e.date) == 1)
-  object$meta <- object$meta[match(names(object$text), object$meta$id),]
-  ind <- object$meta$date >= s.date & object$meta$date <= e.date
+#' @rdname filterDate
+#' @export
+filterDate.default <- function(text, meta,
+  s.date = min(meta$date, na.rm = TRUE),
+  e.date = max(meta$date, na.rm = TRUE), ...){
+  
+  stopifnot(is.textmeta(textmeta(meta = meta, text = text)),
+    length(s.date) == 1, length(e.date) == 1)
+  
+  meta <- meta[match(names(text), meta$id),]
+  ind <- meta$date >= s.date & meta$date <= e.date
   ind[is.na(ind)] <- FALSE
-  object$meta <- object$meta[ind, ]
-  object$text <- object$text[match(object$meta$id, names(object$text))]
-  if(returnTextmeta) return(object)
-  return(object$text)
+  meta <- meta[ind, ]
+  
+  text <- text[match(meta$id, names(text))]
+  
+  invisible(text)
+}
+
+#' @rdname filterDate
+#' @export
+filterDate.textmeta <- function(object,
+  s.date = min(object$meta$date, na.rm = TRUE),
+  e.date = max(object$meta$date, na.rm = TRUE),
+  filtermeta = TRUE, ...){
+
+  stopifnot(is.textmeta(object), is.logical(filtermeta), length(filtermeta) == 1)
+  
+  text <- NextMethod("filterDate", object = object$text, text = object$text,
+    meta = object$meta, s.date = s.date, e.date = e.date)
+  
+  object$text <- text
+  if(filtermeta){
+    object$meta <- object$meta[object$meta$id %in% names(object$text),]
+  }
+  return(object)
 }
